@@ -1,9 +1,8 @@
 package App::githook_perltidy::post_commit;
 use strict;
 use warnings;
-use parent 'App::githook_perltidy';
 
-our $VERSION = '0.11.5';
+our $VERSION = '0.11.5_1';
 
 sub run {
 
@@ -19,7 +18,7 @@ App::githook_perltidy::post_commit - git post-commit hook
 
 =head1 VERSION
 
-0.11.5 (2018-06-27)
+0.11.5_1 (2017-04-28)
 
 =head1 DESCRIPTION
 
@@ -35,7 +34,7 @@ Mark Lawrence E<lt>nomad@null.netE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2011-2018 Mark Lawrence <nomad@null.net>
+Copyright 2011-2016 Mark Lawrence <nomad@null.net>
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
